@@ -7,7 +7,7 @@ from timeit import time
 from pdb import set_trace
 from optparse import OptionParser
 
-__version__ = '0.3.0'
+__version__ = '0.3.1'
 __author__ = 'Dane Springmeyer (dbsgeo [ -a- ] gmail.com)'
 __copyright__ = 'Copyright 2009, Dane Springmeyer'
 __license__ = 'GPLv2'
@@ -73,16 +73,23 @@ class ComposeDebug(Compose):
         self.debug_msg('SRS: %s' % self.map.srs)
         if self.map.proj_obj.srid:
             self.debug_msg('SRID: %s' % self.map.proj_obj.srid)
-        self.debug_msg('Map envelope: %s' % self.map.envelope())
+        self.debug_msg('Map extent: %s' % self.map.envelope())
+        self.debug_msg('Map long/lat bbox: %s' % self.map.lon_lat_bbox())
         self.debug_msg('Map center: %s' % self.map.envelope().center())
-        self.debug_msg('Map scale denonminator: %s' % self.map.scale_denominator())
+        self.debug_msg('Map long/lat center: %s' % self.map.lon_lat_bbox().center())
+        self.debug_msg('Map scale denominator: %s' % self.map.scale_denominator())
         if self.layers:
             self.debug_msg('Active layers: %s' % self.map.active_layers())
         if self.map.layers_bounds():
-            self.debug_msg('Bounds of all layers: %s' % self.map.layers_bounds())
+            self.debug_msg('Extent of all layers: %s' % self.map.layers_bounds())
+            self.debug_msg('Long/lat extent of all layers: %s' % self.map.lon_lat_layers_bounds())
+            self.debug_msg('Long/lat center of all layers: %s' % self.map.lon_lat_layers_bounds().center())
         if self.verbose:
             lyrs = self.map.intersecting_layers()
-            self.debug_msg("Layers intersecting map: [%s]" % ', '.join([l.name for l in lyrs]))
+            if not len(lyrs):
+                self.debug_msg("No layers intersecting map!",warn=True)
+            else:
+                self.debug_msg("Layers intersecting map: [%s]" % ', '.join([l.name for l in lyrs]))
             self.debug_msg("At current scale of '%s'..." % self.map.scale(),print_time=False)
             for lyr in lyrs:
                 if not l.visible(self.map.scale()):
@@ -357,4 +364,4 @@ if __name__ == '__main__':
         import cProfile
         cProfile.run('main()', sort=1)
     else:
-        main()
\ No newline at end of file
+        main()
